Skip to contents

These functions are deprecated, and will be removed in a future update.

Usage

import_inops(expose, lib.loc = .libPaths(), ...)

import_LL(package, selection, lib.loc = .libPaths())

Arguments

expose, package

a single string, giving the name of the R-package.

lib.loc

a character vector describing the location of R library trees to search through.

...

further arguments passed to import_from or import_ls

selection

a character vector of function names (both regular functions and infix operators).
Internal functions or re-exported functions are not supported.

Value

See import_from.

Examples


import_inops("stringi")
#> Warning: `import_inops()` is deprecated and will be removed;
#>   please use `import_from(..., ls = import_ls(..., type = "infix"))` instead
#> calling:
#> `import_from(..., ls = import_ls(..., type = "infix"))`
#> Import & method registration complete
import_LL("stringi", "stri_c")
#> Warning: `import_LL()` is deprecated and will be removed;
#>     please use `import_from(...)` instead
#> calling:
#> `import_from(...)`
#> Import & method registration complete